function [UDA,VEDA,RAc,RAs,RAr,RAl]=gagvflca
% GAGVFLCA: Generate parmeters for Fuzzy Automata, 
%              by interpolation in vague environment of an AGV
%
%                     [UDC,VEDC,RCSva,RCSvd,RCRva,RCRvd,RCLva,RCLvd]=gagvflcf
%
%          Where [UDC,VEDC,RCSva,RCSvd,RCRva,RCRvd,RCLva,RCLvd] are the FLC parameters.
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

% The universes considered for the control are:

U = [-1:.01:1];   % Components of the universe of discourse
UP = [0:.005:1];

Us  = UP;          % State universe
Usc = Us;
Uss = Us;
Usr = Us;
Usl = Us;

Uev = U;          % Distance of the path from the guide point of the AGV
Upv = UP;          % Path Valid

Url = UP;         % Distance measured by the left ultrasonic sensor
Urr = UP;         % Distance measured by the right ultrasonic sensor
Urm = UP;         % Distance measured by the middle ultrasonic sensor
Ualm = UP;        % Max left turn angle without side collision
Uarm = UP;        % Max riht turn angle without side collision

  % Universe of discourse

UDA = [Usc;Uss;Usr;Usl;Uev;Upv;Url;Urr;Urm;Ualm;Uarm;Us];

% The piecewise linear scaling functions are
%  (by their break points or value):

  % States

sz = 0;		% zero
sm = 0.5;	% middle
sl = 1;		% large

SPs =[ sz,  1;
      sm,  3;
      sl,  1];

%SPs =[ sz,  1;
%       sl,  1];

  % Distance of the path from the guide point

evnvl= -1;       % negativ very large
evnl = -.99;      % negativ large
evz  = 0;        % zero
evpl = .99;       % positiv large
evpvl = 1;       % positiv very large

SPev=[evnvl,100;
       evnl,  1;
        evz,  0;
       evpl,  1;
      evpvl,100];

  % Path Valid

pnv = 0;		% Path Not Valid
pv = 1;		% Path Valid

SPpv =[ pnv,  100;
         pv,  100];

  % Distance measured by the ultrasonic sensors

rz = 0;        % zerus
rzd = 0;         % left scalling factor
rzu = 10;        % right scalling factor

rs = .5;        % small
rsd = 10;         % left scalling factor
rsu = 20;        % right scalling factor

rl = .611;         % large
rld = 20;        % left scalling factor
rlu = 0;         % right scalling factor

  % Distance measured by the left ultrasonic sensor

rlz = rz;        % zerus
rls = rs;        % small
rll = rl;        % large

SPrl = [rz, rzd, rzu;
        rs, rsd, rsu;
        rl, rld, rlu];

  % Distance measured by the right ultrasonic sensor

rrz = rz;        % zerus
rrs = rs;        % small
rrl = rl;        % large

SPrr = SPrl;

  % Distance measured by the middle ultrasonic sensor

%rms = .4;         % small
%rmsd = 0;         % left scalling factor
%rmsu = 20;        % right scalling factor
%rml = .51;         % large
%rmld = 20;         % left scalling factor
%rmlu = 0;         % right scalling factor

rms = .3;         % small
rmsd = 0;         % left scalling factor
rmsu = 20;        % right scalling factor

rml = .51;         % large
rmld = 5;         % left scalling factor
rmlu = 0;         % right scalling factor

SPrm = [rms, rmsd, rmsu;
        rml, rmld, rmlu];

  % Max turn angle without side collision

ams = 0;          % small
amsd = 0;         % left scalling factor
amsu = 1;        % right scalling factor

amm = .2;          % middle
ammd = 1;         % left scalling factor
ammu = 10;        % right scalling factor

aml = .3;         % large
amld = 10;        % left scalling factor
amlu = 0;         % right scalling factor

  % Max left turn angle without side collision

alms = ams;        % small
almm = amm;        % middle
alml = aml;        % large

SPalm = [ams, amsd, amsu;
         amm, ammd, ammu;
         aml, amld, amlu];

  % Max right turn angle without side collision

arms = ams;        % small
armm = amm;        % middle
arml = aml;        % large

SParm = SPalm;

% Generating the scaling functions

SFs = gscnfunc(Us,SPs); % States
SFev = gscnfunc(Uev,SPev);  % Distance of the path from the guide point
SFpv = gscnfunc(Upv,SPpv);  % Path Valid
SFrl = gscnfunc(Url,SPrl); % Distance measured by the left ultrasonic sensor
SFrr = gscnfunc(Urr,SPrr); % Distance measured by the right ultrasonic sensor
SFrm = gscnfunc(Urm,SPrm); % Distance measured by the middle ultrasonic sensor
SFalm = gscnfunc(Ualm,SPalm); % Max left turn angle without side collision
SFarm = gscnfunc(Uarm,SParm); % Max riht turn angle without side collision

% Generating the vague environment

VEs = gvagenv(Us,SFs); % States
VEsc = VEs;
VEss = VEs;
VEsr = VEs;
VEsl = VEs;
VEev = gvagenv(Uev,SFev);  % Distance of the path from the guide point
VEpv = gvagenv(Upv,SFpv);  % Path Valid
VErl = gvagenv(Url,SFrl); % Distance measured by the left ultrasonic sensor
VErr = gvagenv(Urr,SFrr); % Distance measured by the right ultrasonic sensor
VErm = gvagenv(Urm,SFrm); % Distance measured by the middle ultrasonic sensor
VEalm = gvagenv(Ualm,SFalm); % Max left turn angle without side collision
VEarm = gvagenv(Uarm,SFarm); % Max riht turn angle without side collision

  % Vague universe of discourse

VEDA = [VEsc;VEss;VEsr;VEsl;VEev;VEpv;VErl;VErr;VErm;VEalm;VEarm;VEs];

%
% The table of rules for control of differential and resultant speed;
%

% The Rulebases

  % The Rulebase of the fuzzy automata, voting for one of the states
  % (All the rulebases are the same)

  % NaN: (Not a number) independent from the antecedent

x = nan;  % Independency from the rule antacedent

% Path tratcking and collision avoidance
%RAc =   [  sc,  ss,  sr,  sl,   ev,  pv,  rl,  rr,  rm,  alm,  arm,   sc;...]
RAc  =   [   x,   x,   x,   x,  evz,  pv,   x,   x, rml,    x,    x,   sl;
             x,   x,   x,   x,    x,  pv,   x,   x,   x,    x, arms,   sz;
             x,   x,   x,   x,    x,  pv,   x,   x,   x, alms,    x,   sz;
             x,   x,   x,   x,    x, pnv,   x,   x,   x,    x,    x,   sz ];

% Collision aviodance
%RAs =   [  sc,  ss,  sr,  sl,   ev,  pv,  rl,  rr,  rm,  alm,  arm,   ss;...]
RAs  =   [   x,   x,   x,   x,    x,  pv,   x,   x, rms,    x,    x,   sl;
             x,   x,   x,   x,    x,  pv, rlz,   x,   x,    x,    x,   sl;
             x,   x,   x,   x,    x,  pv,   x, rrz,   x,    x,    x,   sl;
             x,   x,   x,   x,    x,  pv,   x,   x,   x, alms,    x,   sl;
             x,   x,   x,   x,    x,  pv,   x,   x,   x,    x, arms,   sl;
             x,   x,   x,   x,    x,  pv,   x,   x, rml,    x,    x,   sz;
             x,   x,   x,   x,    x, pnv,   x,   x,   x,    x,    x,   sz ];

% Collision aviodance with right tendency
%RAr =   [  sc,  ss,  sr,  sl,   ev,  pv,  rl,  rr,  rm,  alm,  arm,   sr;...]
RAr  =   [  sl,   x,   x,   x,evnvl,  pv,   x,   x,   x,    x,    x,   sl;
             x,   x,  sl,   x,    x, pnv,   x,   x,   x,    x,    x,   sl;
             x,   x,   x,   x,  evz,  pv,   x,   x, rml,    x,    x,   sz;
             x,   x,   x,  sl,    x,   x,   x,   x,   x,    x,    x,   sz ];

% Collision aviodance with left tendency
%RAl =   [  sc,  ss,  sr,  sl,   ev,  rl,  pv,  rr,  rm,  alm,  arm,   sl;...]
RAl  =   [  sl,   x,   x,   x,evpvl,  pv,   x,   x,   x,    x,    x,   sl;
             x,   x,   x,  sl,    x, pnv,   x,   x,   x,    x,    x,   sl;
             x,   x,   x,   x,  evz,  pv,   x,   x, rml,    x,    x,   sz;
             x,   x,  sl,   x,    x,   x,   x,   x,   x,    x,    x,   sz ];

