function [UDM,VEDM,Rmva,Rmvd]=gagvflcm
% GAGVFLCM: Generate parmeters for the metacontrol, 
%              by interpolation in vague environment of an AGV
%
%                     [UDM,VEDM,Rmva,Rmvd]=gagvflcm
%
%          Where [UDM,VEDM,Rmva,Rmvd] are the FLC parameters.
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

% The universes considered for the control are:

U = [-1:.01:1];   % Components of the universe of discourse
UP = [0:.005:1];

Us = UP;          % Similarity universe

Uva = UP;         % Average speed of the AGV
Uvd = U;          % Differential speed of the AGV

  % Universe of discourse

UDM = [Us;Us;Us;Us;Uva;Uvd];

% The piecewise linear scaling functions are
%  (by their break points or value):

nl = -1;		% negative large
z = 0;		% zero
m = 0.5;	% middle
l = 1;		% large

SPs  =[ z,  0;
        m,  5;
        l,  0];

SPva =[ z,  1;
        l,  1];

SPvd =[nl,  1;
        l,  1];

SFs = gscnfunc(Us,SPs);  % NonLinear Scaling Function (linear: gsclfunc)
SFva = gscnfunc(Uva,SPva);  % NonLinear Scaling Function (linear: gsclfunc)
SFvd = gscnfunc(Uvd,SPvd);  % NonLinear Scaling Function (linear: gsclfunc)

VEs = gvagenv(Us,SFs);  % Vague Environment
VEva = gvagenv(Uva,SFva);  % Vague Environment
VEvd = gvagenv(Uvd,SFvd);  % Vague Environment

  % Vague universe of discourse

VEDM = [VEs;VEs;VEs;VEs;VEva;VEvd];

%
% The table of rules for control of differential and resultant speed;
%

% The Rulebases

  % The rules are rows Rvd = [ev,ek,rl,rr,rm,alm,arm,vd;...]

  % NaN: (Not a number) independent from the antecedent

x = nan;  % Independency from the rule antacedent

  % The Rulebase of the fuzzy metacontrol,

  % The rules are rows
  % S: Actual System States
  % CS: The Conclusion of the actual controller
  % Rm =  [ S1,S2,S3,S4,CSx;]

Rmva =     [ l, z, z, z,      l;
             z, l, z, z,      l;
             z, z, l, z,      l;
             z, z, z, l,      l];

Rmvd =     [ l, z, z, z,      l;
             z, l, z, z,      l;
             z, z, l, z,      l;
             z, z, z, l,      l];

