function [path,pos]=genapath(agv,rpath)
%GENAPATH: Generate the path parameters and the starting position
%         Path: Circular arc and straight if rpath > 0
%               and straight only if rpath == 0
%
%                            [path,pos]=genapath(agv,rpath)
%
%          Where agv is the description of the vehicle,
%          rpath is the radius of the path,
%          path is the description of the path,
%          pos is the description of the agv's initial positon.
%
%          Path:
%
%            lx : length of the first streight
%            r  : radius
%            ly : length of the last streight
%
%                               |
%                               | ly
%                               |
%                           r  /
%                      lx     /
%                   _________/
%
%          pos:
%
%            xk,yk : the main point of the AGV
%            fi    : angle of the AGV
%            vao   : previous speed
%            dfio  : previous angular velocity
%
%          agv:
%
%            w : distance of the sensor from the main point of the AGV
%            d : distance of the wheels
%            ds : widt of the path sensing
%            wagv : width of the AGV
%            lagv : length of the AGV
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 2,error('Invalid number of arguments!');end

if length(agv) ~= 5
  error('Invalid AGV descriptor!');
end

if length(rpath) ~= 1
  error('Invalid path radius value!');
end

w = agv(1);  % the distance of the guide and the main point of the agv

if rpath == 0  % straight only

  path(1) = 0;  % length of the first streight
  path(2) = 0;  % radius
  path(3) = 7.*w;  % length of the last streight

    % Starting position

  pos(1) = 0;  % the main point of the AGV
  pos(2) = 0;  %
  pos(3) = 0;  % angle of the AGV

else  % circular arc and straight

  path(1) = 2.*w;  % length of the first streight
  path(2) = rpath;  % radius
%  path(3) = 4.*w;  % length of the last streight  % old system
  path(3) = 5.5.*w;  % length of the last streight

    % Starting position

  lx = path(1);  % length of the first streight
  r = path(2);   % radius
  ly = path(3);  % length of the last streight

  pos(1) = -lx;    % the main point of the AGV
  pos(2) = -r;     %
  pos(3) = pi./2;  % angle of the AGV

end  % end if

pos(4) = 1;      % previous speed (full speed)
pos(5) = 0;      % previous angular velocity

