function [obst]=genobst(obsobj)
%GENOBST: Generate the obstacle parameters
%
%          [obst]=genobst(obsobj)
%
%          Where obst are the obstacle parameters,
%          obsobj are the obstacle objects.
%
%          obst:
%
%            x,y : position of the obstacle
%            r  : radius of the obstacle
%
%          obsobj:
%
%            'userdata',[off,x,y,robs]:
%              off = -1;  % off, on flags
%              on = 1;
%              x,y : position
%              robs : radius
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 1,error('Invalid number of arguments!');end

off = -1;  % flags
on = 1;

[m,n] = size(obsobj);  % the max number of obstacles is n

obst = [];  % clear the obstacle parameters

for i=1 : n

    % The obstacle parameters

  userdata = get(obsobj(i),'userdata');

  if userdata(1) == on  % the obstacle is active

    x = userdata(2);  % position
    y = userdata(3);
    robs = userdata(4);  % radius

      % add to obstacle parameters

    obst = [[x,y,robs];obst];

  end  % if

end  % for i

