function [pathp]=gpathp(path,ds)
%GPATHP: Generate the points of the path
%
%                            [pathp]=gpathp(path,ds)
%
%          Where pathp is the points of the path 
%          path is the description of the path,
%          ds is the size of the steps.
%
%          Path:
%
%            lx : length of the first streight
%            r  : radius
%            ly : length of the last streight
%
%                               |
%                               | ly
%                               |
%                           r  /
%                      lx     /
%                   _________/
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 2,error('Invalid number of arguments!');end

if length(path) ~= 3
  error('Invalid Path!');
end

lx = path(1);  % length of the first streight
r = path(2);  % radius
ly = path(3);  % length of the last streight

cs = 1; % counter for the path

for i=-lx : ds : 0  % streight

  pathp(cs,:) = [i,-r];
  cs = cs+1;

end % for i

for i=ds : ds : (r.*pi./2)  % circle

  pathp(cs,:) = [(r.*sin(i./r)),(-r.*cos(i./r))];
  cs = cs+1;

end % for i

for i=ds : ds : ly  % streight

  pathp(cs,:) = [r,i];
  cs = cs+1;

end % for i

