function [scf]=gsclfunc(u,psc)
%GSCLFUNC:  Generate the linear scaling function SCF
%
%                            [SCF]=gsclfunc(U,PSC)
%
%          Where SCF is the scaling function to generate,
%          U is the universe, PSC contains the points of the scaling function
%          as P1,S1l,S1r;P2,S2l,s2r;... where P the point, 
%          Sl the left, Sr the right scaling function value.
%
%          The change of the scaling function between P0,S0 P1,S1 is linear.
%

% Fuzzy Inference by Interpolation in Vague Environment toolbox for MATLAB
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs


if nargin ~= 2,error('Invalid number of arguments!');end

[m,n]=size(u);

[l,k]=size(psc);

if k>3 | (k==1 & l>1)
  error('Invalid matrix type of scaling function points!');
end

if l>1  % more points

	if k==2  % Sl and Sr are the same

  	for i=1:m
  	for j=1:n

    	if u(i,j) < psc(1,1)  % first
      	scf(i,j) = psc(1,2);
    	end

    	for p=1:l-1

      	if u(i,j) >= psc(p,1) & u(i,j) < psc(p+1,1)
        	p1 = psc(p,1);
        	p2 = psc(p+1,1);
        	s1 = psc(p,2);
        	s2 = psc(p+1,2);
        	scf(i,j)=((s2-s1)./(p2-p1)).*(u(i,j)-p1)+s1;
      	end

    	end %for p

    	if u(i,j) >= psc(l,1)  %last
	      scf(i,j) = psc(l,2);
	    end

  	end %for j
  	end %for i

	else  % Sl and Sr are different

  	for i=1:m
  	for j=1:n

    	if u(i,j) < psc(1,1)  % first
      	scf(i,j) = psc(1,2);
    	end

    	for p=1:l-1

      	if u(i,j) >= psc(p,1) & u(i,j) < psc(p+1,1)
        	p1 = psc(p,1);
        	p2 = psc(p+1,1);
        	s1 = psc(p,3);
        	s2 = psc(p+1,2);
        	scf(i,j)=((s2-s1)./(p2-p1)).*(u(i,j)-p1)+s1;
      	end

    	end %for p

    	if u(i,j) >= psc(l,1)  %last
	      scf(i,j) = psc(l,3);
	    end

  	end %for j
  	end %for i

	end %if

else  % only one element

  if k==1        % single value
    c = psc;
  else           % single point
    c = psc(1,2);
  end

  for i=1:m
  for j=1:n

    scf(i,j) = c;

  end %for j
  end %for i

end

