function [ve]=gvagenv(u,scf)
%GVAGENV:  Generate vague environment VE
%
%                            [VE]=gvagenv(U,SCF)
%
%          Where VE is the vague environment to generate,
%          U is the universe, SCF is the scalling function
%

% Fuzzy Inference by Interpolation in Vague Environment toolbox for MATLAB
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs


if nargin ~= 2,error('Invalid number of arguments!');end

if length(u) ~= length(scf)
    error('Input arguments must be the same length!');
end

[m,n] = size(u);

for k=1 : m

  % Trapezoid sum for vague environment

  e = diff(u(k,:)) .* (scf(k,1:n-1) + scf(k,2:n))/2;

  ve(k,1) = 0;

  for i=1 : n-1
    ve(k,i+1) = ve(k,i) + e(i);
  end % for i

end % for k

