function agvobj=initagvo
%INITAGVO: Init the AGV object
%
%                    agvobj=initagvo
%
%          Where agvobj is the AGV object.
%
%          agvobj:
%
%            agvobj=[body,...  % Body of the AGV
%              guidezone,...  % The guide zone
%              wheels,...  % The wheels
%              mainpos,...  % The main point
%              guidep,...  % The guide point
%              agvline,...  % The AGV line 
%                           % (line betweem the guige and main point)
%              sens];  % The ultrasonic sensors
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 0,error('Invalid number of arguments!');end

  % Body of the AGV

body = line( ...
  'color','c', ...
  'linestyle','-', ...
  'erase','xor', ...
  'xdata',0,'ydata',0);

  % The guide zone

guidezone = line( ...
  'color','r', ...
  'linestyle','-', ...
  'erase','xor', ...
  'xdata',0,'ydata',0);

  % The wheels

wheels = line( ...
  'color','c', ...
  'linestyle','none', ...
  'marker','o', ...
  'erase','xor', ...
  'xdata',0,'ydata',0);

  % The main point

mainpos = line( ...
  'color','g', ...
  'linestyle','none', ...
  'marker','o', ...
  'erase','xor', ...
  'xdata',0,'ydata',0);

  % The guide point

guidep = line( ...
  'color','r', ...
  'linestyle','none', ...
  'marker','*', ...
  'erase','xor', ...
  'xdata',0,'ydata',0);

  % The AGV line

agvline = line( ...
  'color','r', ...
  'linestyle',':', ...
  'erase','xor', ...
  'xdata',0,'ydata',0);

  % The ultrasonic sensors

sens = line( ...
  'color','b', ...
  'linestyle','none', ...
  'marker','o', ...
  'erase','xor', ...
  'xdata',0,'ydata',0);

agvobj=[body,...  % Body of the AGV
  guidezone,...  % The guide zone
  wheels,...  % The wheels
  mainpos,...  % The main point
  guidep,...  % The guide point
  agvline,...  % The AGV line (line betweem the guige and main point)
  sens];  % The ultrasonic sensors

