function obsobj=initobso(obssize,maxobsnum)
%INITOBSO: Init the obstacle objects
%
%                    obsobj=initobso(obssize,maxobsnum)
%
%          Where obsobj are the obstacle objects,
%          maxosnum is the maximal number of the obstacles.
%
%          obsobj:
%
%            'userdata',[off,x,y,robs]:
%              off = -1;  % off, on flags
%              on = 1;
%              x,y : position
%              robs : radius
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 2,error('Invalid number of arguments!');end

a = (0 : .01 : 1).*2.*pi;

robs = obssize./2;

off = -1;  % flags
on = 1;

for i=1 : maxobsnum

    % The obstacle object

  obsobj(i) = patch(0,0,'m');

  x = -robs;  % initial position
  y = i.*robs;

  xo = robs.*sin(a)+x;  % initial position
  yo = robs.*cos(a)+y;

  set(obsobj(i),...
    'visible','off',...
    'userdata',[off,x,y,robs],...
    'xdata',xo,'ydata',yo);

end  % for i

