function plagvlin(agv,rpos)
%PLAGVLIN: Plot AGV lines (trajectories) on screen
%
%                    plagvlin(agv,rpos)
%
%          Where agv is the description of the vehicle,
%          rpos is the description of the agv's positons.
%
%          agv:
%
%            w : distance of the sensor from the main point of the AGV
%            d : distance of the wheels
%            ds : widt of the path sensing
%            wagv : width of the AGV
%            lagv : length of the AGV
%
%          rpos:
%
%            xk,yk : the main point of the AGV
%            fi    : angle of the AGV
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 2,error('Invalid number of arguments!');end

if length(agv) ~= 5
  error('Invalid AGV descriptor!');
end

[m,n] = size(rpos);

if n ~= 3
  error('Invalid positions!');
end

w = agv(1);  % the distance of the guide and the main point of the agv
ds = agv(3);  % widt of the path sensing

% Draw the line of the main point

hold on;  % Draw in the same window
plot(rpos(:,1),rpos(:,2),'g-');  % main line

% Line of the guide points

gpos = [];  % clear

for i=1 : m

  xk = rpos(i,1);
  yk = rpos(i,2);
  fi = rpos(i,3);
  sinfi = sin(fi);
  cosfi = cos(fi);
  wsinfi = w.*sinfi;
  wcosfi = w.*cosfi;
  dssinfi = ds.*sinfi./2;
  dscosfi = ds.*cosfi./2;

  xv = xk+wsinfi;  % position of the guide point
  yv = yk+wcosfi;
  gsax = xk+wsinfi-dscosfi;  % guide section
  gsay = yk+wcosfi+dssinfi;
  gsbx = xk+wsinfi+dscosfi;
  gsby = yk+wcosfi-dssinfi;

  [gpos] = [gpos;[xv,yv,gsax,gsay,gsbx,gsby]];

end  % for i

% Draw the line of the guide point

hold on;  % Draw in the same window
plot(gpos(:,1),gpos(:,2),'r:');  % guide line

hold on;  % Draw in the same window
plot(gpos(:,3),gpos(:,4),'r--');  % guide section
hold on;  % Draw in the same window
plot(gpos(:,5),gpos(:,6),'r--');  % guide section

