function [m,d1]=pnbdist(p1,p2,p)
%PNBDIST: Distance of a near by point from a line
%
%                            [m,d1]=pnbdist(p1,p2,p)
%
%          Where p1, p2 are the two points of the line near by,
%          p is the point to calculate the distance of,
%          m is the distance of p from the line,
%          d1 is the distance of p1 to the nearest point to p 
%             on the line p1,p2.
%          m<0 if p is not near by on the "right side".
%
%          p1, p2, p:
%
%            x,y : point
%

% Fuzzy Path Tracking for Automated Guided Vehicle
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 3,error('Invalid number of arguments!');end

if length(p1) ~= 2
  error('Invalid point description!');
end

if length(p2) ~= 2
  error('Invalid point description!');
end

if length(p) ~= 2
  error('Invalid point description!');
end

x1 = p1(1);  % local variables
y1 = p1(2);

x2 = p2(1);  % local variables
y2 = p2(2);

x = p(1);  % local variables
y = p(2);

  % Calculation the distance of a line p1,p2 and a point p

dx = x2-x1;
dy = y2-y1;

d =  sqrt(dx.^2+dy.^2);  % the distance of the two point
alf = atan2(dx,dy);  % atan(dx/dy) the angle of the line

r12 = (x-x1).^2 + (y-y1).^2;
r22 = (x-x2).^2 + (y-y2).^2;

  % d1 is the distance of p1 to the nearest point to p on the line

d1 = (r12 - r22 + d.^2)./(2.*d);

  % m is the distance of p from the line p1,p2

m = sqrt(r12 - d1.^2);

  % checking if p on the "right side" of the p1,p2 line

beta = atan2(x-x1,y-y1);  % atan(dx/dy)

da = beta-alf;

if da > pi | da < 0

  m = -1;  % not on the "right side"

end;  % if

