function [dist]=vagdist(u,ve,p1,p2)
%VAGDIST:  Calculate the distance of two points in vague environment
%
%                            [DIST]=vagdist(U,VE,P1,P2)
%
%          Where DIST is the distance of the two points,
%          U is the universe, VE is the vague invironment,
%          P1,P2 is the two points, whose distance we are interested in.
%
%          If Pi=NaN, then the vague distance is not valid (dist=0)
%

% Fuzzy Inference by Interpolation in Vague Environment toolbox for MATLAB
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs


if nargin ~= 4,error('Invalid number of arguments!');end

if length(u) ~= length(ve)
    error('Input arguments must be the same length!');
end

[m,n] = size(u);

for k=1 : m  % the number of the dimension

  if isnan(p1(k)) | isnan(p2(k))  % not a valid vague distance

    dist(k) = 0;  % indifferent (not existing) rule antecedent

  elseif isinf(p1(k)) | isinf(p2(k))  % not a valid vague distance

    dist(k) = p2(k)-p1(k);  % infinite distance never fitting observation

  else  % valid vague distance

    if min(p1(k),p2(k)) < u(k,1) | max(p1(k),p2(k)) > u(k,n)
      error('The points are out of range!');
    end

      % i is the index of the min distance from p1

    [dm,i] = min(abs(u(k,:)-p1(k)));

      % j is the index of the min distance from p2

    [dm,j] = min(abs(u(k,:)-p2(k)));

      % The distance in vague environment is:

    dist(k) = ve(k,j) - ve(k,i);

  end  % if

end % for k

